#!/bin/bash
#
# This script will create a near-mirror image of your WordPress installation  plugins, themes, galleries 
# and all. The script will duplicate your database and make the necessary changes to the copy to reflect the 
# changed URL. Look through this script carefully: depending on your system configuration, there are a few 
# things you may need to change. Always back up your site and your database before running any scripts 
# (especially my scripts).
 
DATE=$(date +'%Y-%m-%d_%H-%M-%S')
WORKDIR="/srv/www/htdocs/krazyworks/solobox"
 
if [ ${1} ]
then
	SOURCE="${1}"
else
	echo "Must specify source directory. Exiting..."
	exit 1
fi
 
if [ ! -d "${WORKDIR}/${SOURCE}" ]
then
	echo "Source ${WORKDIR}/${SOURCE} not found. Exiting..."
	exit 1
fi
 
if [ ${2} ]
then
	TARGET="${2}"
else
	echo "Must specify target directory. Exiting..."
	exit 1
fi
 
configure() {
	HTTPUSER="wwwrun"
	HTTPGROUP="www"
	DBNAME=$(grep DB_NAME "${WORKDIR}/${SOURCE}/wp-config.php" | awk -F"'" '{print $4}')
	echo -n "Enter database username: " ; read DBUSER
	echo -n "Enter $DBUSER password: " ; stty -echo ; read DBPASS ; stty echo ; echo ""
	echo -n "Enter new database name: " ; read DBNEW
	MYSQL="/usr/bin/mysql -u${DBUSER} -p${DBPASS}"
	MYSQLDUMP="/usr/bin/mysqldump -u${DBUSER} -p${DBPASS}"
	DBHOME="/var/lib/mysql"
	RSYNC="/usr/local/bin/rsync -avu"
}
 
db_copy() {
	echo "Copying database $DBNAME to $DBNEW"
	echo "CREATE DATABASE $DBNEW;" | $MYSQL
	echo "GRANT ALL PRIVILEGES ON ${DBNEW}.* to ${DBUSER}@'%' IDENTIFIED BY '$DBPASS' WITH GRANT OPTION ;" |\
	$MYSQL
	#$MYSQLDUMP $DBNAME | $MYSQL $DBNEW
	/etc/init.d/mysql stop
	$RSYNC "${DBHOME}/${DBNAME}/" "${DBHOME}/${DBNEW}/"
	/etc/init.d/mysql start
}
 
modify_wp_conf() {
	echo "Modifying new database"
	cat "${WORKDIR}/${TARGET}/wp-config.php" | \
	sed "s/define('DB_NAME', '$DBNAME')/define('DB_NAME', '$DBNEW')/g" > /tmp/wp-copy.tmp
	mv /tmp/wp-copy.tmp "${WORKDIR}/${TARGET}/wp-config.php"
 
	options_table=$($MYSQL $DBNEW << "	EOF" | grep "_options$" | tail -1
	SHOW TABLES ;
	quit
	EOF )
 
	echo "SHOW TABLES;" | $MYSQL $DBNEW | grep -v "Tables_in_$DBNEW" | while read TABLE
	do
		echo "SHOW COLUMNS FROM $TABLE;" | $MYSQL $DBNEW | awk -F'\t' '{print $1}' |\
		grep -v "Field" | while read COLUMN
		do
			echo "update $TABLE set ${COLUMN} = replace(${COLUMN}, '/${SOURCE}', '/${TARGET}');" |\
			$MYSQL $DBNEW
		done
	done
}
 
site_copy() {
	echo "Copying site from ${SOURCE} to ${TARGET}"
	mkdir "${WORKDIR}/${TARGET}"
	$RSYNC "${WORKDIR}/${SOURCE}/" "${WORKDIR}/${TARGET}/"
	chown -R ${HTTPUSER}:${HTTPGROUP} "${WORKDIR}/${TARGET}"
}
 
configure
db_copy
site_copy
modify_wp_conf
